GantTask class

Model representing a single task in the Gantt chart.

Constructors

GantTask({required String id, required String title, required DateTime start, required DateTime end, required Color color, double? progress, String? subtitle, List<String>? dependsOn})

Properties

color Color
final
dependsOn List<String>?
final
end DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
progress double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
final
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited