PlexCollection class

Constructors

PlexCollection(String name, Database _database)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

countWithFinder(Finder finder) Future<int>
Count records matching the given finder.
delete(Map<String, dynamic> record) Future
deleteById(int id) Future
deleteWithFinder(Finder finder) Future<int>
Delete all records matching the given finder.
find({int? limit, int? offset}) Future<List<Map<String, dynamic>>>
findWithFinder(Finder finder) Future<List<Map<String, dynamic>>>
Find records matching the given finder.
getAll() Future<List<Map<String, dynamic>>>
getById(int id) Future<Map<String, dynamic>?>
insert(Map<String, dynamic> record) Future
insertAll(List<Map<String, dynamic>> records) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Map<String, dynamic> record) Future
watchWithFinder(Finder finder) Stream<List<Map<String, dynamic>>>
Stream of records matching the given finder; emits whenever data changes.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ID_KEY → const String