PlexDb class

Properties

hashCode int
The hash code for this object.
no setterinherited
initialized bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache({String? urlPattern}) Future<void>
Clear cache. If urlPattern is provided, only keys containing the pattern are deleted.
closeDatabase() Future<void>
deleteFromCache(String key) Future<void>
Delete a cached value by key.
getCacheKeys() Future<List<String>>
List all cache keys.
getCollection(String name) PlexCollection
getEntityCollection<T extends PlexEntity>(String name, {required T fromJson(Map<String, dynamic> map), required Map<String, dynamic> toJson(T entity)}) PlexEntityCollection<T>
getFromCache(String key) Future<Map<String, dynamic>?>
Get a cached value by key. Returns null if not found.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putInCache(String key, Map<String, dynamic> value) Future<void>
Store a value in the cache.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initialize(PlexDbConfig dbConfig, {List<PlexDbMigration> migrations = const []}) Future<PlexDb>