PlexQueryable<T extends PlexEntity> class abstract

Interface for collections that support querying. Implemented by PlexEntityCollection.

Implementers

Constructors

PlexQueryable()

Properties

collection PlexCollection
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

mapFromMaps(List<Map<String, dynamic>> maps) List<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited