PlexAuthInterceptor class

Interceptor that adds an Authorization: Bearer <token> header from a token provider.

Inheritance

Constructors

PlexAuthInterceptor(Future<String> tokenProvider())

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenProvider Future<String> Function()
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(Object error, StackTrace stack) Future<PlexApiResponse>
Called when an exception occurs. Return a PlexApiResponse (typically PlexError).
inherited
onRequest(String url, Map<String, String> headers) Future<Map<String, String>>
Called before the request is sent. Return modified headers.
override
onResponse(PlexApiResponse response) Future<PlexApiResponse>
Called after the response is received. Return the (possibly modified) response.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited