PlexRetryInterceptor class

Configuration for retry behavior. Used by the networking pipeline when this interceptor is in the chain.

Inheritance

Constructors

PlexRetryInterceptor({int maxAttempts = 3, List<int> retryOnStatusCodes = const [500, 502, 503]})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
final
retryOnStatusCodes List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(Object error, StackTrace stack) Future<PlexApiResponse>
Called when an exception occurs. Return a PlexApiResponse (typically PlexError).
inherited
onRequest(String url, Map<String, String> headers) Future<Map<String, String>>
Called before the request is sent. Return modified headers.
inherited
onResponse(PlexApiResponse response) Future<PlexApiResponse>
Called after the response is received. Return the (possibly modified) response.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited