PlexSuccess<T> class

Inheritance

Constructors

PlexSuccess(String? body, int code)
PlexSuccess.bytes(Uint8List bytes, int code)

Properties

code int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
response ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited