guards property
Optional guards. If rule is set and guards is empty, PlexRoleGuard is used automatically.
Implementation
final List<PlexRouteGuard> guards;
Optional guards. If rule is set and guards is empty, PlexRoleGuard is used automatically.
final List<PlexRouteGuard> guards;