PlexGetXRouter class

GetX-based implementation of PlexRouter. Default router for PlexApp.

Implemented types

Constructors

PlexGetXRouter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

back({dynamic result}) → void
Pop the current route.
override
buildApp(PlexRouterConfig config) Widget
Builds the root app widget (e.g. GetMaterialApp or MaterialApp.router).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offAndToNamed<T>(String path, {dynamic arguments, Map<String, String>? parameters}) Future<T?>?
Replace current route with a named route (e.g. login → home).
override
to<T>(dynamic widget, {dynamic arguments}) Future<T?>?
Push a widget onto the navigation stack.
override
toNamed<T>(String path, {dynamic arguments, Map<String, String>? parameters}) Future<T?>?
Navigate to a named route.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited