PlexAuthGuard class
Redirects to loginPath if currentUser is null.
- Inheritance
-
- Object
- PlexRouteGuard
- PlexAuthGuard
Constructors
- PlexAuthGuard({String loginPath = '/Login'})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redirect(
PlexRouteContext context) → Future< String?> -
Returns null to allow navigation, or a route path to redirect to.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited