PlexRoleGuard class

Redirects (excludes route) if user lacks the required rule.

Inheritance

Constructors

PlexRoleGuard(String rule)

Properties

hashCode int
The hash code for this object.
no setterinherited
rule String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redirect(PlexRouteContext context) Future<String?>
Returns null to allow navigation, or a route path to redirect to.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited