PlexLoginConfig class
Constructors
-
PlexLoginConfig({required Future<
PlexUser?> onLogin(BuildContext context, String email, String password), required PlexUser userFromJson(Map<String, dynamic> userData), Widget additionalWidgetsTop(BuildContext context)?, Widget additionalWidgetsAboveLoginButton(BuildContext context)?, Widget additionalWidgetsBottom(BuildContext context)?, String? debugUsername, String? debugPassword, String? username, String? password, int? passwordMinLength, int? passwordMaxLength, Widget createWidget(BuildContext context)?, bool useBackground = false, PlexBackgroundType backgroundType = PlexBackgroundType.neoGlass, PlexLoginLayout layout = PlexLoginLayout.split, String? brandHeadline, String? brandSubtitle, String? formTitle, String? formHint})
Properties
- additionalWidgetsAboveLoginButton → Widget Function(BuildContext context)?
-
final
- additionalWidgetsBottom → Widget Function(BuildContext context)?
-
final
- additionalWidgetsTop → Widget Function(BuildContext context)?
-
final
- backgroundType → PlexBackgroundType
-
final
-
Optional footer on the split brand panel. Version name is used when null.
final
- brandHeadline → String?
-
Optional copy on the split brand panel. When null, PlexAppInfo.title is used.
final
- brandSubtitle → String?
-
Optional supporting line on the split brand panel. Omitted when null.
final
- createWidget → Widget Function(BuildContext context)?
-
final
- debugPassword → String?
-
final
- debugUsername → String?
-
final
- formHint → String?
-
Optional muted hint under formTitle. Omitted when null.
final
- formTitle → String?
-
Optional heading above the split-layout form fields.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → PlexLoginLayout
-
Visual layout. Defaults to PlexLoginLayout.split.
final
-
onLogin
→ Future<
PlexUser?> Function(BuildContext context, String email, String password) -
final
- password → String?
-
final
- passwordMaxLength → int?
-
final
- passwordMinLength → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useBackground → bool
-
final
-
userFromJson
→ PlexUser Function(Map<
String, dynamic> userData) -
final
- username → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited