diScope property
String?
get
diScope
Override to return a scope name for this screen. If non-null, the scope is closed in dispose.
Implementation
String? get diScope => null;
Override to return a scope name for this screen. If non-null, the scope is closed in dispose.
String? get diScope => null;