PlexTheme class

This class will hold theme related information

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appTextTheme TextTheme?
getter/setter pair
appTheme ThemeData?
getter/setter pair
inputBackgroundColor Color
Input fill is a surface token. Previously this was accidentally the same red as inputErrorColor.
no setter
inputErrorColor Color
no setter
no setter
no setter
selectionColor Color
no setter

Static Methods

getActiveTheme(BuildContext context) ThemeData
Initial theme data for the app
getBrightnessMode() ThemeMode
Check theme is brightness
getTextTheme(BuildContext context) TextTheme
getThemeByBrightness(Brightness brightness) ThemeData
isDarkMode(BuildContext context) bool
Check theme is dark or light
isMaterial3() bool
Theme is always Material 3. Prefs key UseMaterial3 is ignored.
randomColor() Color
setBrightnessMode(ThemeMode value) → void
Set theme brightness
setMaterial3(bool value) → void
Deprecated no-op. Material 2 is no longer supported.

Constants

defaultFontFamily → const String
defaultSeedColor → const Color
Generic professional blue-gray seed (Material Blue Grey 500, #607D8B).