PlexLogSink class abstract
Sink for forwarding log output (e.g. to Sentry, Crashlytics).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
PlexLogLevel level, String tag, String message, {Object? error, StackTrace? stack}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited