Plex class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
back(
{dynamic result}) → void -
configure(
PlexRouter router) → void - Configure the router. Called by PlexApp on init.
-
offAndToNamed<
T> (String path, {dynamic arguments, Map< String, String> ? parameters}) → Future<T?> ? -
to<
T> (dynamic to, {dynamic arguments}) → Future< T?> ? -
toNamed<
T> (String path, {dynamic arguments, Map< String, String> ? parameters}) → Future<T?> ?