PlexXlsx class

Minimal OOXML (.xlsx) writer. Cells are inline strings so Excel/LibreOffice can open the file without a sharedStrings table.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({required String title, required List columns, required List<List> rows}) List<int>
sanitizeSheetName(String title) String
Excel sheet names: max 31 chars, no : \ / ? * [ ], not empty, not wrapped in a single quote.