CustomColumnSizer class
Unused. Column sizing is handled by PlexDataGrid.
Kept so historic CustomColumnSizer() call sites still compile after
Syncfusion ColumnSizer was removed.
- Annotations
-
- @Deprecated('Unused. Column sizing is handled by PlexDataGrid.')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited