PlexDataTableHeaderCell.custom constructor

PlexDataTableHeaderCell.custom(
  1. String columnName,
  2. Widget? cell, {
  3. bool isNumber = false,
  4. WidthMode widthMode = WidthMode.auto,
  5. bool showOrderByControl = true,
  6. bool showFilterControl = true,
})

For custom design and handling of cell use this constructor. columnName is optional cell is required for custom cell

Implementation

PlexDataTableHeaderCell.custom(this.columnName, this.cell,
    {this.isNumber = false,
    this.widthMode = WidthMode.auto,
    this.showOrderByControl = true,
    this.showFilterControl = true});