PlexDataTableValueCell.custom constructor

PlexDataTableValueCell.custom(
  1. String columnName,
  2. String textValue,
  3. Widget widget, {
  4. bool numberField = false,
})

For custom design and handling of cell use this constructor. value is optional cell is required for custom cell

Implementation

PlexDataTableValueCell.custom(
  this.columnName,
  String textValue,
  Widget widget, {
  bool numberField = false,
})  : value = PlexComparableWidget(widget, textValue),
      cellValue = textValue,
      isWidget = true {
  isNumber = numberField || value is int || value is double;
}