PlexAdvanceDataTableAdapter class
Maps PlexAdvanceDataTable header/cell models onto PlexDataGrid columns.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cellFor(
List< PlexDataTableValueCell> row, String columnName) → PlexDataTableValueCell? -
columns(
List< PlexDataTableHeaderCell> headers) → List<PlexDataGridColumn< List< >PlexDataTableValueCell> > -
excelHeaders(
List< PlexDataTableHeaderCell> headers) → List -
excelRows(
List< PlexDataTableHeaderCell> headers, List<List< rows) → List<PlexDataTableValueCell> >List> -
valueFor(
List< PlexDataTableValueCell> row, String columnName) → Object?