PlexTableSource class

Data source for PlexDataTableUnified.

Properties

dataStream Stream<List<List<PlexDataCell>>>?
final
fetchFn Future<List<List<PlexDataCell>>> Function(int page)?
final
hashCode int
The hash code for this object.
no setterinherited
rows List<List<PlexDataCell>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PlexTableSourceType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

list(List<List<PlexDataCell>> rows) PlexTableSource
Create a source from an in-memory list.
paginated(Future<List<List<PlexDataCell>>> fetchFn(int page)) PlexTableSource
Create a source that fetches pages asynchronously.
stream(Stream<List<List<PlexDataCell>>> dataStream) PlexTableSource
Create a source from a stream of row lists.