stream static method
Create a source from a stream of row lists.
Implementation
static PlexTableSource stream(Stream<List<List<PlexDataCell>>> dataStream) {
return PlexTableSource._(type: PlexTableSourceType.stream, dataStream: dataStream);
}
Create a source from a stream of row lists.
static PlexTableSource stream(Stream<List<List<PlexDataCell>>> dataStream) {
return PlexTableSource._(type: PlexTableSourceType.stream, dataStream: dataStream);
}