PlexFormFieldButton constructor

const PlexFormFieldButton({
  1. Key? key,
  2. PlexFormFieldGeneric properties = const PlexFormFieldGeneric.empty(),
  3. PlexButtonType buttonType = PlexButtonType.elevated,
  4. FocusNode? focusNode,
  5. Widget? buttonIcon,
  6. Widget? buttonTrailingIcon,
  7. dynamic buttonClick()?,
  8. ButtonStyle? buttonStyle,
  9. PlexButtonSize size = PlexButtonSize.md,
  10. bool loading = false,
  11. bool expanded = false,
})

Creates a unified button widget.

The properties parameter provides basic configuration like title, margins, etc. The buttonType parameter determines which style of button to render. size, loading, expanded, and buttonTrailingIcon are additive; defaults match the previous unlabeled / idle / intrinsic-width behavior.

Implementation

const PlexFormFieldButton({
  super.key,
  this.properties = const PlexFormFieldGeneric.empty(),
  this.buttonType = PlexButtonType.elevated,
  this.focusNode,
  this.buttonIcon,
  this.buttonTrailingIcon,
  this.buttonClick,
  this.buttonStyle,
  this.size = PlexButtonSize.md,
  this.loading = false,
  this.expanded = false,
});