PlexFormFieldGeneric class

Constructors

PlexFormFieldGeneric({String? title, String? semanticLabel, bool enabled = true, String? helperText, bool useMargin = true, double cornerRadius = PlexDim.small, EdgeInsets margin = const EdgeInsets.symmetric(horizontal: PlexDim.medium, vertical: PlexDim.small)})
const
PlexFormFieldGeneric.empty()
const
PlexFormFieldGeneric.title(String? title, {String? semanticLabel})
const

Properties

cornerRadius double
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
margin EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
title String?
final
useMargin bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited