PlexLookup<T> class
Searchable single-select field. Not a replacement for PlexFormFieldAutoComplete or PlexFormFieldDropdown.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PlexLookup
- Available extensions
Constructors
-
PlexLookup({Key? key, required List<
T> items, required String labelOf(T item), T? value, ValueChanged<T?> ? onChanged, String hint = 'Search', String? label, bool enabled = true, String subtitleOf(T item)?}) -
const
Properties
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- labelOf → String Function(T item)
-
final
-
onChanged
→ ValueChanged<
T?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitleOf → String Function(T item)?
-
final
- value → T?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PlexLookup< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plexRxWidget(
PlexRx rx) → PlexRxWidget -
Available on Widget, provided by the PlexRxWidgetExt extension
-
scaleAnim(
{int durationMillis = 500, bool repeat = false}) → Widget -
Available on Widget, provided by the WidgetsUtils extension
-
scaleAnim2(
{int durationMillis = 500, bool repeat = false}) → Widget -
Available on Widget, provided by the WidgetsUtils extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited