PlexMiniTable class
Compact read-only table for dashboard tiles.
Does not replace PlexDataTable or PlexDataGrid.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PlexMiniTable
- Available extensions
Constructors
-
PlexMiniTable({Key? key, required List<
PlexMiniTableColumn> columns, required List<List< rows, bool zebra = false, PlexMiniTableDensity density = PlexMiniTableDensity.comfortable, bool plainHead = false, ValueChanged<String> >int> ? onRowTap, String emptyMessage = 'Nothing to show'}) -
const
Properties
-
columns
→ List<
PlexMiniTableColumn> -
final
- density → PlexMiniTableDensity
-
final
- emptyMessage → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onRowTap
→ ValueChanged<
int> ? -
final
- plainHead → bool
-
final
-
rows
→ List<
List< String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zebra → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plexRxWidget(
PlexRx rx) → PlexRxWidget -
Available on Widget, provided by the PlexRxWidgetExt extension
-
scaleAnim(
{int durationMillis = 500, bool repeat = false}) → Widget -
Available on Widget, provided by the WidgetsUtils extension
-
scaleAnim2(
{int durationMillis = 500, bool repeat = false}) → Widget -
Available on Widget, provided by the WidgetsUtils extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited