PlexMiniTableColumn class

Column definition. Cells are plain Strings.

Constructors

PlexMiniTableColumn({required String id, required String header, PlexMiniTableAlign align = PlexMiniTableAlign.left, bool numeric = false, double? width})
const

Properties

align PlexMiniTableAlign
final
hashCode int
The hash code for this object.
no setterinherited
final
id String
final
numeric bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited