PlexMobileTallyItem class

One SKU / line for PlexMobileList.

qty is display-only. The parent owns increments and decrements.

Constructors

PlexMobileTallyItem({required String id, required String title, String? subtitle, int qty = 0, String? unit, String? barcode})
const

Properties

barcode String?
Optional scan code. Default PlexMobileTally matching uses id or this.
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
qty int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final
unit String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited