onScanMatch property
Fired after a scan or typed submit increments a matched line.
Implementation
final ValueChanged<PlexMobileTallyItem>? onScanMatch;
Fired after a scan or typed submit increments a matched line.
final ValueChanged<PlexMobileTallyItem>? onScanMatch;