PlexProgressBar class

Horizontal progress / completion bar with optional label and value.

Inheritance
Available extensions

Constructors

PlexProgressBar({Key? key, double value = 0, double max = 100, String? label, bool showValue = false, PlexProgressBarSize size = PlexProgressBarSize.md, PlexProgressBarTone tone = PlexProgressBarTone.brand, bool indeterminate = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
indeterminate bool
When true, shows an animated bar with no determinate value.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Label shown above the bar.
final
max double
Maximum value. Defaults to 100.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValue bool
Show the percentage on the right.
final
size PlexProgressBarSize
Bar thickness. Defaults to PlexProgressBarSize.md.
final
tone PlexProgressBarTone
Fill color. Defaults to PlexProgressBarTone.brand.
final
value double
Current value. Ignored when indeterminate is true. Defaults to 0.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plexRxWidget(PlexRx rx) PlexRxWidget

Available on Widget, provided by the PlexRxWidgetExt extension

scaleAnim({int durationMillis = 500, bool repeat = false}) Widget

Available on Widget, provided by the WidgetsUtils extension

scaleAnim2({int durationMillis = 500, bool repeat = false}) Widget

Available on Widget, provided by the WidgetsUtils extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited