PlexStatTile class

Denser KPI tile without card chrome — use inside PlexStatGrid.

Inheritance
Available extensions

Constructors

PlexStatTile({Key? key, required String label, required String value, String? unit, String? hint, String? delta, PlexStatDirection direction = PlexStatDirection.flat, bool invert = false, IconData? icon, PlexStatIconTone iconTone = PlexStatIconTone.info, PlexStatSurface tone = PlexStatSurface.standard, PlexStatStripe? stripe, double? progress, VoidCallback? onTap, Widget? child})
const

Properties

child Widget?
final
delta String?
final
direction PlexStatDirection
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
icon IconData?
final
iconTone PlexStatIconTone
final
invert bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
onTap VoidCallback?
final
progress double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripe PlexStatStripe?
final
tone PlexStatSurface
final
unit String?
final
value String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plexRxWidget(PlexRx rx) PlexRxWidget

Available on Widget, provided by the PlexRxWidgetExt extension

scaleAnim({int durationMillis = 500, bool repeat = false}) Widget

Available on Widget, provided by the WidgetsUtils extension

scaleAnim2({int durationMillis = 500, bool repeat = false}) Widget

Available on Widget, provided by the WidgetsUtils extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited