PlexWizardStep class

One page in a PlexWizard.

Constructors

PlexWizardStep({required String title, required Widget child, String? subtitle, bool optional = false, bool validator()?})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
optional bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final
validator bool Function()?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited