PlexAccessibilityConfig class
Configuration for Plex accessibility features.
Constructors
- PlexAccessibilityConfig({bool highContrast = false, bool largeText = false, bool reduceMotion = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- highContrast → bool
-
Forces high-contrast ColorScheme.
final
- largeText → bool
-
Applies 1.3× text scale factor.
final
- reduceMotion → bool
-
Disables PlexBackground animations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const PlexAccessibilityConfig
- Default config with all options disabled.