injectSingletonLazyAsync<T> function
dynamic
injectSingletonLazyAsync<
T>( - Future<T> builder(), {
- String? tag,
})
Implementation
injectSingletonLazyAsync<T>(Future<T> Function() builder, {String? tag}) {
var plexDependency = _PlexInjector<T>.singletonLazyAsync(builder, tag);
if (_isInjected(plexDependency, tag: tag)) {
throw Exception("This type of object is already registered in plex. If you want to register other dependency with same object Please mark it with 'Tag'");
}
_injectors.add(plexDependency);
}