PlexLocalizationConfig class
Configuration for Plex localization.
Constructors
-
PlexLocalizationConfig({required List<
Locale> supportedLocales, required PlexStrings translationLoader(Locale locale)}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedLocales
→ List<
Locale> -
Locales supported by the app.
final
- translationLoader → PlexStrings Function(Locale locale)
-
Loads PlexStrings for the given
locale.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited