PlexRoleGuard class
Redirects (excludes route) if user lacks the required rule.
- Inheritance
-
- Object
- PlexRouteGuard
- PlexRoleGuard
Constructors
- PlexRoleGuard(String rule)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redirect(
PlexRouteContext context) → Future< String?> -
Returns null to allow navigation, or a route path to redirect to.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited