PlexRouter class abstract
Abstract router interface. Implementations wrap GetX, GoRouter, or other navigation backends.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
back(
{dynamic result}) → void - Pop the current route.
-
buildApp(
PlexRouterConfig config) → Widget - Builds the root app widget (e.g. GetMaterialApp or MaterialApp.router).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offAndToNamed<
T> (String path, {dynamic arguments, Map< String, String> ? parameters}) → Future<T?> ? - Replace current route with a named route (e.g. login → home).
-
to<
T> (dynamic widget, {dynamic arguments}) → Future< T?> ? - Push a widget onto the navigation stack.
-
toNamed<
T> (String path, {dynamic arguments, Map< String, String> ? parameters}) → Future<T?> ? - Navigate to a named route.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited