PlexRouterConfig class
Configuration passed to PlexRouter.buildApp.
Constructors
-
PlexRouterConfig({required String title, required ThemeData theme, required ThemeData darkTheme, required ThemeMode themeMode, required ScrollBehavior scrollBehavior, required String initialRoute, required String unknownRouteName, required Widget unknownRouteBuilder(BuildContext context), required Map<
String, WidgetBuilder> routes, Map<String, String> ? pathOverrides, Iterable<LocalizationsDelegate> ? localizationsDelegates, Iterable<Locale> supportedLocales = const [Locale('en')], Widget builder(BuildContext context, Widget? child)?}) -
const
Properties
- builder → Widget Function(BuildContext context, Widget? child)?
-
Optional builder to wrap the app's navigator (e.g. for accessibility).
final
- darkTheme → ThemeData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialRoute → String
-
final
-
localizationsDelegates
→ Iterable<
LocalizationsDelegate> ? -
Localization delegates for MaterialApp.
final
-
pathOverrides
→ Map<
String, String> ? -
For GoRouter: route name -> parameterized path (e.g. "/orders/:id").
final
-
routes
→ Map<
String, WidgetBuilder> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollBehavior → ScrollBehavior
-
final
-
supportedLocales
→ Iterable<
Locale> -
Supported locales for the app.
final
- theme → ThemeData
-
final
- themeMode → ThemeMode
-
final
- title → String
-
final
- unknownRouteBuilder → Widget Function(BuildContext context)
-
final
- unknownRouteName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited