PlexDim class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- extraHuge → const double
- extraLarge → const double
- extraLargeMinus → const double
- half → const double
- huge → const double
- large → const double
- largeMinus → const double
- largePlus → const double
- medium → const double
- mediumPlus → const double
- mini → const double
- small → const double
- smallest → const double
- smallMedium → const double
- 4px-grid steps that were missing from the original scale. Existing fields above keep their historic values.
- zero → const double