PlexFontSize class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- body → const double
- bodyLarge → const double
- caption → const double
- Additional type-scale steps. Existing fields above keep historic values.
- displayExtraLarge → const double
- displayLarge → const double
- displayMedium → const double
- displaySmall → const double
- extraLarge → const double
- large → const double
- medium → const double
- normal → const double
- small → const double
- smallest → const double
- title → const double