PlexAsyncAction<T> class
Wraps an async task with automatic loading/error handling. Use with PlexViewModel.runAction, PlexViewViewModel.runAction, or PlexState.runAction.
Constructors
-
PlexAsyncAction(Future<
T> _task(), {void onError(Object error, StackTrace stack)?, void onSuccess(T result)?}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onError → void Function(Object error, StackTrace stack)?
-
final
- onSuccess → void Function(T result)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited