PlexDataTableValueCell class
Cell model for PlexAdvanceDataTable.
Public fields match the historic constructor shape (columnName, value,
numberField, custom widget). This type no longer extends Syncfusion
DataGridCell.
Constructors
- PlexDataTableValueCell.custom(String columnName, String textValue, Widget widget, {bool numberField = false})
-
For custom design and handling of cell use this constructor.
value is optional
cellis required for custom cell - PlexDataTableValueCell.text(String columnName, dynamic value, {bool numberField = false})
-
valueis required as it is text only cell
Properties
Methods
-
clone(
{dynamic newValue}) → PlexDataTableValueCell -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited