PlexCalendarEvent class
Timed item shown on PlexCalendar.
Constructors
- PlexCalendarEvent({required String id, required DateTime start, required String title, DateTime? end, Color? color, PlexCalendarRecurrence? recurrence, String? occurrenceOf})
-
const
Properties
- color → Color?
-
final
- end → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- occurrenceOf → String?
-
Master event id when this row is an expanded occurrence.
final
- recurrence → PlexCalendarRecurrence?
-
Optional repeat rule. Expanded by PlexCalendar when
PlexCalendar.expandRecurrence is true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
final
- title → String
-
final
Methods
-
copyWith(
{String? id, DateTime? start, String? title, DateTime? end, Color? color, PlexCalendarRecurrence? recurrence, String? occurrenceOf}) → PlexCalendarEvent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited