PlexCalendarEvent class

A single event for PlexCalendar.

Constructors

PlexCalendarEvent({required String title, required DateTime start, required DateTime end, Color? color, dynamic data})
const

Properties

color Color?
final
data → dynamic
final
end DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited