PlexChartSeries class
One plotted series.
Constructors
-
PlexChartSeries({required String name, required List<
double> data, Color? color, PlexChartType? mark}) -
const
Properties
- color → Color?
-
final
-
data
→ List<
double> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mark → PlexChartType?
-
Per-series mark for PlexChartType.combo and PlexChartType.trellis
(
barorline). Null uses the combo default (first series bars, remaining series lines) or PlexChart.trellisInnerType inside a trellis facet.final - name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited