PlexDataListItem class
One row in PlexDataList.
Constructors
- PlexDataListItem({String? id, required String title, String? subtitle, Widget? trailing, String? value, String? meta, String? delta, PlexDataListDirection direction = PlexDataListDirection.flat, double? progress, IconData? icon, PlexDataListTone tone = PlexDataListTone.neutral, String? avatarName, String? tag, bool done = false, Color? color})
-
const
Properties
- avatarName → String?
-
final
- color → Color?
-
final
- delta → String?
-
final
- direction → PlexDataListDirection
-
final
- done → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- id → String?
-
final
- meta → String?
-
final
- progress → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
- tag → String?
-
final
- title → String
-
final
- tone → PlexDataListTone
-
final
- trailing → Widget?
-
final
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited