PlexFormFieldButton constructor
const
PlexFormFieldButton({
- Key? key,
- PlexFormFieldGeneric properties = const PlexFormFieldGeneric.empty(),
- PlexButtonType buttonType = PlexButtonType.elevated,
- FocusNode? focusNode,
- Widget? buttonIcon,
- Widget? buttonTrailingIcon,
- dynamic buttonClick()?,
- ButtonStyle? buttonStyle,
- PlexButtonSize size = PlexButtonSize.md,
- bool loading = false,
- bool expanded = false,
Creates a unified button widget.
The properties parameter provides basic configuration like title, margins, etc.
The buttonType parameter determines which style of button to render.
size, loading, expanded, and buttonTrailingIcon are additive; defaults
match the previous unlabeled / idle / intrinsic-width behavior.
Implementation
const PlexFormFieldButton({
super.key,
this.properties = const PlexFormFieldGeneric.empty(),
this.buttonType = PlexButtonType.elevated,
this.focusNode,
this.buttonIcon,
this.buttonTrailingIcon,
this.buttonClick,
this.buttonStyle,
this.size = PlexButtonSize.md,
this.loading = false,
this.expanded = false,
});