PlexMobileTally class
Shop-floor tally: PlexMobileList plus scan / typed-code increment.
Qty stays with the parent. A scan or typed submit finds a line via
matchCode (or id / barcode) then calls onIncrement and onScanMatch.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PlexMobileTally
- Available extensions
Constructors
-
PlexMobileTally({Key? key, required List<
PlexMobileTallyItem> items, ValueChanged<PlexMobileTallyItem> ? onIncrement, ValueChanged<PlexMobileTallyItem> ? onDecrement, ValueChanged<PlexMobileTallyItem> ? onTap, ValueChanged<PlexMobileTallyItem> ? onScanMatch, bool enableScanner = true, bool matchCode(PlexMobileTallyItem item, String code)?}) -
const
Properties
- enableScanner → bool
-
When false, the Scan button does not push PlexScanner.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
PlexMobileTallyItem> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- matchCode → bool Function(PlexMobileTallyItem item, String code)?
-
Override default match (
code == item.id || code == item.barcode).final -
onDecrement
→ ValueChanged<
PlexMobileTallyItem> ? -
final
-
onIncrement
→ ValueChanged<
PlexMobileTallyItem> ? -
final
-
onScanMatch
→ ValueChanged<
PlexMobileTallyItem> ? -
Fired after a scan or typed submit increments a matched line.
final
-
onTap
→ ValueChanged<
PlexMobileTallyItem> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PlexMobileTally> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plexRxWidget(
PlexRx rx) → PlexRxWidget -
Available on Widget, provided by the PlexRxWidgetExt extension
-
scaleAnim(
{int durationMillis = 500, bool repeat = false}) → Widget -
Available on Widget, provided by the WidgetsUtils extension
-
scaleAnim2(
{int durationMillis = 500, bool repeat = false}) → Widget -
Available on Widget, provided by the WidgetsUtils extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited